import unittest
from .test_draw_ui_detection_results import TestDrawUIDetectionResults
from .test_export import TestExport
from .test_hawkeyezero_init import TestHawkeyeZeroInit
from .test_is_model_avaliable import TestIsModelAvailable
from .test_load_path import TestLoadPath
from .test_load_yolo import TestLoadYolo
from .test_train import TestTrain
from .test_use_model import TestUseModel
from .test_val import TestVal


if __name__ == '__main__':
    unittest.main()